@@ -1,12 +1,10 @@
-#!/usr/bin/env python2
-
 from translate.convert import csv2po, po2csv, test_convert
 from translate.misc import wStringIO
 from translate.storage import csvl10n, po
 from translate.storage.test_base import first_translatable, headerless_len
 
 
-class TestPO2CSV:
+class TestPO2CSV(object):
 
     def po2csv(self, posource):
         """helper that converts po source to csv source without requiring files"""
@@ -65,7 +63,7 @@ msgstr "Eerste lyn\nTweede lyn"
         unit = self.singleelement(csvfile)
         assert unit.source == "First line\nSecond line"
         assert unit.target == "Eerste lyn\nTweede lyn"
-        pofile = self.csv2po(str(csvfile))
+        pofile = self.csv2po(bytes(csvfile))
         unit = self.singleelement(pofile)
         assert unit.source == "First line\nSecond line"
         assert unit.target == "Eerste lyn\nTweede lyn"
@@ -107,12 +105,12 @@ msgstr "Vind\\Opsies"
         """Tests that single quotes are preserved correctly"""
         minipo = '''msgid "source 'source'"\nmsgstr "target 'target'"\n'''
         csvfile = self.po2csv(minipo)
-        print(str(csvfile))
+        print(bytes(csvfile))
         assert csvfile.findunit("source 'source'").target == "target 'target'"
         # Make sure we don't mess with start quotes until writing
         minipo = '''msgid "'source'"\nmsgstr "'target'"\n'''
         csvfile = self.po2csv(minipo)
-        print(str(csvfile))
+        print(bytes(csvfile))
         assert csvfile.findunit(r"'source'").target == r"'target'"
         # TODO check that we escape on writing not in the internal representation
 
