@@ -1,9 +1,7 @@
-#!/usr/bin/env python2
-
 from translate.convert import po2moz, test_convert
 
 
-class TestPO2Moz:
+class TestPO2Moz(object):
     pass
 
 
