@@ -22,6 +22,8 @@
 .. seealso:: http://en.wikipedia.org/wiki/French_language
 """
 
+from __future__ import unicode_literals
+
 import re
 
 from translate.lang import common
@@ -33,15 +35,15 @@ def guillemets(text):
         prefix = match.group(1)
         # Let's see that we didn't perhaps match an XML tag property like
         # <a href="something">
-        if prefix == u"=":
+        if prefix == "=":
             return match.group(0)
-        return u"%s«\u00a0%s\u00a0»" % (prefix, match.group(2))  # \u00a0 is NBSP
+        return "%s«\u00a0%s\u00a0»" % (prefix, match.group(2))  # \u00a0 is NBSP
 
     # Check that there is an even number of double quotes, otherwise it is
     # probably not safe to convert them.
     if text.count(u'"') % 2 == 0:
         text = re.sub('(.|^)"([^"]+)"', convertquotation, text)
-    singlecount = text.count(u"'")
+    singlecount = text.count("'")
     if singlecount:
         if singlecount == text.count(u'`'):
             text = re.sub("(.|^)`([^']+)'", convertquotation, text)
@@ -54,18 +56,18 @@ def guillemets(text):
 class fr(common.Common):
     """This class represents French."""
 
-    validaccel = (u"abcdefghijklmnopqrstuvwxyz"
-                  u"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                  u"1234567890"
-                  u"é"
-                  u"É")
+    validaccel = ("abcdefghijklmnopqrstuvwxyz"
+                  "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+                  "1234567890"
+                  "é"
+                  "É")
 
     # According to http://french.about.com/library/writing/bl-punctuation.htm,
     # in French, a space is required both before and after all two- (or more)
     # part punctuation marks and symbols, including : ; « » ! ? % $ # etc.
     puncdict = {}
-    for c in u":;!?#":
-        puncdict[c] = u"\u00a0%s" % c
+    for c in ":;!?#":
+        puncdict[c] = "\u00a0%s" % c
     # TODO: consider adding % and $, but think about the consequences of how
     # they could be part of variables
 
@@ -80,5 +82,5 @@ class fr(common.Common):
         text = super(cls, cls).punctranslate(text)
         # We might get problems where we got a space in URIs such as
         # http ://
-        text = text.replace(u"\u00a0://", "://")
+        text = text.replace("\u00a0://", "://")
         return guillemets(text)
